========
controls
========


.. automodule:: camelot.view.controls
   :members:

.. toctree::

   abstract_widget.rst
   action_widget.rst
   actionsbox.rst
   appscheme.rst
   busy_widget.rst
   calculator.rst
   combobox_input_dialog.rst
   dashboard.rst
   decorated_line_edit.rst
   delegates/index.rst
   editors/index.rst
   exception.rst
   field_label.rst
   filter_operator.rst
   filterlist.rst
   formview.rst
   inheritance.rst
   liteboxview.rst
   modeltree.rst
   navpane2.rst
   progress_dialog.rst
   search.rst
   standalone_wizard_page.rst
   statusbar.rst
   tableview.rst
   user_translatable_label.rst
   view.rst
